@@ -1,5 +1,6 @@
 #include "controller.h"
 #include <QDeclarativeView>
+#include <QDeclarativeEngine>
 #include <QDebug>
 #include <QFile>
 #include <QDir>
@@ -28,7 +29,12 @@ Controller::Controller(QObject *parent) :
     QObject(parent) {
     converter = new QProcess(this);
     connect(converter, SIGNAL(started()), this, SIGNAL(conversionStarted()));
-    connect(converter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(conversionFinished(int, QProcess::ExitStatus)));    
+    connect(converter, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(conversionFinished(int, QProcess::ExitStatus)));
+#ifdef Q_OS_SYMBIAN
+    isSymbian = true;
+#else
+    isSymbian = false;
+#endif
 }
 
 void Controller::setView(QmlApplicationViewer *view) {
@@ -44,6 +50,10 @@ void Controller::toggleState() {
     }
 }
 
+bool Controller::osIsSymbian() const {
+    return isSymbian;
+}
+
 void Controller::keepDisplayOn() {
 #ifdef Q_WS_MAEMO_5
     QDBusConnection systemDbusConnection = QDBusConnection::systemBus();
@@ -87,7 +97,7 @@ QString Controller::getLanguage() const {
 
     QSqlDatabase db;
     db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.setDatabaseName(m_view->engine()->offlineStoragePath().append("/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite"));
     db.open();
 
     QSqlQuery query("select value from settings where setting = 'language'");
@@ -97,7 +107,7 @@ QString Controller::getLanguage() const {
             langCode = query.value(0).toString();
         }
     }
-    //    qDebug() << langCode;
+    //        qDebug() << langCode;
     db.close();
     return langCode;
 }
@@ -142,7 +152,7 @@ bool Controller::widgetInstalled() const {
 void Controller::getMediaPlayerFromDB() {
     QSqlDatabase db;
     db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.setDatabaseName(m_view->engine()->offlineStoragePath().append("/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite"));
     db.open();
 
     QSqlQuery query("select value from settings where setting = 'mediaPlayer'");
@@ -164,7 +174,7 @@ void Controller::getMediaPlayerFromDB() {
 QStringList Controller::getProxyFromDB() const {
     QSqlDatabase db;
     db = QSqlDatabase::addDatabase("QSQLITE");
-    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.setDatabaseName(m_view->engine()->offlineStoragePath().append("/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite"));
     db.open();
 
     QSqlQuery query;
@@ -194,7 +204,7 @@ bool Controller::xTubeInstalled() const {
 #ifdef Q_WS_MAEMO_5
     path = "/opt/usr/share/qmltube/qml/qmltube/scripts/xtube.js";
 #else
-    path = "/home/stuart/N900/qmltube/qml/qmltube/scripts/xtube.js";
+    path = m_view->engine()->baseUrl().toLocalFile().append("qml/qmltube/scripts/xtube.js");
 #endif
     if (QFile::exists(path)) {
         isInstalled = true;
@@ -230,11 +240,9 @@ void Controller::playVideo(const QString &url) {
         QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
         dbus_iface.call("mime_open", url);
     }
-    emit playbackStarted(url);
-
 #else
     if (url.startsWith("http://")) {
-        QFile ytlink("/home/stuart/Videos/ytlink.ram");
+        QFile ytlink("E:/Videos/cutetube/cutetube.ram");
         ytlink.open(QIODevice::WriteOnly);
         ytlink.write(url.toAscii());
         ytlink.close();
@@ -243,8 +251,8 @@ void Controller::playVideo(const QString &url) {
     else {
         QDesktopServices::openUrl(QUrl::fromLocalFile(url));
     }
-    emit playbackStarted(url);
 #endif
+    emit playbackStarted(url);
 }
 
 void Controller::deleteVideo(const QString &path) {
@@ -293,7 +301,6 @@ void Controller::convertToAudio(const QString &input) {
 }
 
 void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatus) {
-
     if ((exitCode == 0) && (exitStatus == QProcess::NormalExit)) {
         QFile output(outputFile);
         if (output.size() > 0) {
