@@ -16,7 +16,7 @@ DownloadManager::DownloadManager(QObject *parent) :
     dlMap["hq"] = 18;
     dlMap["mobile"] = 5;
 
-    connect(this, SIGNAL(gotVideoUrl(QByteArray)), this, SLOT(performDownload(QByteArray)));
+    connect(this, SIGNAL(gotVideoUrl(QUrl)), this, SLOT(performDownload(QUrl)));
 }
 
 void DownloadManager::setNetworkAccessManager(QNetworkAccessManager *manager) {
@@ -72,7 +72,7 @@ void DownloadManager::parseVideoPage() {
         emit statusChanged("failed");
     }
     else {
-        emit gotVideoUrl(videoUrl);
+        emit gotVideoUrl(QUrl::fromEncoded(videoUrl));
         emit qualityChanged(quality);
     }
 }
@@ -111,14 +111,13 @@ void DownloadManager::startDownload(const QString &filePath, const QString &url)
         getVideoUrl(url);
     }
     else {
-        // It's a pR0n video :D
-        performDownload(url.toAscii());
+        performDownload(QUrl(url));
     }
 }
 
-void DownloadManager::performDownload(const QByteArray &videoUrl) {
-    //    qDebug() << QUrl::fromEncoded(videoUrl);
-    QNetworkRequest request(QUrl::fromEncoded(videoUrl));
+void DownloadManager::performDownload(const QUrl &videoUrl) {
+//        qDebug() << videoUrl;
+    QNetworkRequest request(videoUrl);
 
     if (output.size() > 0) {
         request.setRawHeader("Range", "bytes=" + QByteArray::number(output.size()) + "-"); // Set 'Range' header if resuming a download
@@ -151,8 +150,9 @@ void DownloadManager::updateProgress(qint64 bytesReceived, qint64 bytesTotal) {
 
 void DownloadManager::downloadFinished() {
     QUrl redirect = downloadReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+//    qDebug() << redirect;
     if (!redirect.isEmpty()) {
-        performDownload(redirect.toEncoded()); // Follow redirect :P
+        performDownload(redirect); // Follow redirect :P
     }
     else {
         output.close();
