@@ -37,7 +37,7 @@ public slots:
 private slots:
     void parseVideoPage();
     void getVideoUrl(const QString &playerUrl);
-    void performDownload(const QByteArray &videoUrl);
+    void performDownload(const QUrl &videoUrl);
     void updateProgress(qint64 bytesReceived, qint64 bytesTotal);
     void downloadFinished();
     void downloadReadyRead();
@@ -54,7 +54,7 @@ private:
 
 signals:
     void alert(const QString &message);
-    void gotVideoUrl(const QByteArray &videoUrl);
+    void gotVideoUrl(const QUrl &videoUrl);
     void videoUrlError();
     void downloadCompleted(const QString &filename);
     void downloadCancelled();
