@@ -23,17 +23,6 @@ int main(int argc, char *argv[])
     Controller ct;
     YouTube yt;
 
-    QStringList proxyList = ct.getProxyFromDB();
-    QString proxyHost = proxyList.first();
-    if (!proxyHost.isEmpty()) {
-        int proxyPort = proxyList.last().toInt();
-        QNetworkProxy proxy;
-        proxy.setType(QNetworkProxy::HttpCachingProxy);
-        proxy.setHostName(proxyHost);
-        proxy.setPort(proxyPort);
-        QNetworkProxy::setApplicationProxy(proxy);
-    }
-
     QStringList args = app.arguments();
     args.takeFirst();
     if (args.isEmpty()) {
@@ -62,7 +51,7 @@ int main(int argc, char *argv[])
         viewer.addImportPath(QString("/opt/qtm12/imports"));
         viewer.addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
-//        viewer.setViewport(new QGLWidget());
+        //        viewer.setViewport(new QGLWidget());
 
         QDir path;
         path.setPath("/home/user/.config/cutetube");
@@ -73,15 +62,29 @@ int main(int argc, char *argv[])
         if (!path.exists()) {
             path.mkpath("/home/user/MyDocs/.cutetube");
         }
+#endif
+        QStringList proxyList = ct.getProxyFromDB();
+        QString proxyHost = proxyList.first();
+        if (!proxyHost.isEmpty()) {
+            int proxyPort = proxyList.last().toInt();
+            QNetworkProxy proxy;
+            proxy.setType(QNetworkProxy::HttpCachingProxy);
+            proxy.setHostName(proxyHost);
+            proxy.setPort(proxyPort);
+            QNetworkProxy::setApplicationProxy(proxy);
+        }
 
         QString locale = ct.getLanguage();
-
+        QString languagePath;
+#ifdef Q_WS_MAEMO_5
+        languagePath = "/opt/usr/share/qmltube/qml/qmltube/i18n/qml_" + locale;
+#else
+        languagePath = viewer.engine()->baseUrl().toLocalFile().append("qml/qmltube/i18n/qml_" + locale);
+#endif
         QTranslator translator;
-
-        if (translator.load("/opt/usr/share/qmltube/qml/qmltube/i18n/qml_" + locale)) {
+        if (translator.load(languagePath)) {
             app.installTranslator(&translator);
         }
-#endif
 
         viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
         viewer.showFullScreen();
