@@ -16,12 +16,11 @@ function restoreSettings() {
     var catOrder = Settings.getSetting("categoryOrder");
     setCategoryFeeds(catOne, catTwo, catOrder);
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
-    if (Controller.getInstalledMediaPlayers().length > 2) {
-        Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
+    if (Controller.isSymbian) {
+        Controller.setMediaPlayer("Media Player");
     }
     else {
-        Settings.setSetting("mediaPlayer", "cuteTube Player");
-        Controller.setMediaPlayer("cuteTube Player");
+        Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
     }
     YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
     DownloadManager.setDownloadQuality(Settings.getSetting("downloadQuality"));
@@ -255,24 +254,21 @@ function loadPlaybackView(videoList) {
         windowView.currentItem.opacity = 0;
         loader.source = "VideoPlaybackView.qml";
         notificationArea.addTitle(qsTr("Playback View"));
-        loader.item.setPlaylist(videoList);
         toggleControls(false);
         _VIDEO_PLAYING = true;
+        loader.item.setPlaylist(videoList);
         windowView.incrementCurrentIndex();
         loader.item.playbackStopped.connect(stopPlaying);
     }
     else {
         var video = videoList[0];
-        if (video.filePath) {
-            if ((video.quality == "360p") || (video.quality == "480p") || (video.quality == "720p")) {
-                messages.displayMessage(messages._UNABLE_TO_PLAY);
-            }
-            else {
-                Controller.playVideo(video.filePath);
-            }
+        if (video.archive) {
+            Controller.playVideo(video.filePath);
+        }
+        else if (video.xtube) {
+            Controller.playVideo(video.url);
         }
         else {
-            YouTube.gotVideoUrl.connect(Controller.playVideo);
             YouTube.getVideoUrl(video.videoId);
         }
     }
@@ -293,16 +289,16 @@ function search(query, order) {
 
     if (xTubeInstalled) {
         var youporn = /^yp:/i;
-        var youjizz = /^yj:/i;
-        var xhamster = /^xh:/i;
+        var tubeeight = /^t8:/i;
+        var pornhub = /^ph:/i;
         if (youporn.test(query)) {
             loadXtubeVideos("youporn", query.slice(3), order);
         }
-        else if (youjizz.test(query)) {
-            loadXtubeVideos("youjizz", query.slice(3), order);
+        else if (tubeeight.test(query)) {
+            loadXtubeVideos("tube8", query.slice(3), order);
         }
-        else if (xhamster.test(query)) {
-            loadXtubeVideos("xhamster", query.slice(3), order);
+        else if (pornhub.test(query)) {
+            loadXtubeVideos("pornhub", query.slice(3), order);
         }
         else {
             youtubeSearch(query, order);
