@@ -132,16 +132,16 @@ function setDefaultSettings() {
 
     var settings = [ [ "playbackQuality", "hq" ],
                     [ "downloadQuality", "hq" ],
-                    [ "downloadStatus", "paused" ],
-                    [ "downloadPath", "/home/user/MyDocs/.cutetube/" ],
+                    [ "downloadStatus", "queued" ],
+                    [ "downloadPath", Controller.isSymbian ? "E:/Videos/" : "/home/user/MyDocs/.cutetube/" ],
                     [ "categoryFeedOne", "MostRecent"],
                     [ "categoryFeedTwo", "MostViewed"],
                     [ "categoryOrder", "relevance"],
                     [ "safeSearch", "none" ],
                     [ "screenOrientation", "automatic" ],
-                    [ "mediaPlayer", "Media Player" ],
+                    [ "mediaPlayer", "cuteTube Player" ],
                     [ "searchOrder", "relevance" ],
-                    [ "theme", "night" ],
+                    [ "theme", "nightred" ],
                     [ "language", "en" ],
                     [ "proxy", ":"],
                     [ "widgetFeedOne", "_MOST_RECENT_FEED" ],
