@@ -45,6 +45,19 @@ function shareVideo(service) {
     }
 }
 
+function rateVideo(rating) {
+    if (userIsSignedIn()) {
+        if (!video.rating) {
+            toggleBusy(true);
+            likeOrDislike = rating;
+            YouTube.rateVideo(videoId, rating);
+        }
+    }
+    else {
+        messages.displayMessage(messages._NOT_SIGNED_IN);
+    }
+}
+
 function showAddCommentDialog() {
     /* Add a new comment */
 
@@ -100,6 +113,7 @@ function loadComments() {
 
             commentsModel.loading = false;
             commentsList.loaded = true;
+            commentsList.positionViewAtIndex(0, ListView.Beginning);
         }
     }
     doc.open("GET", commentsList.commentsFeed);
