@@ -72,7 +72,12 @@ void YouTube::setAccessToken(const QByteArray &token) {
 
 void YouTube::uploadVideo(const QString &filename, const QString &title, const QString &description, const QString &tags, const QString &category, const bool &isPrivate) {
 
+    emit uploadStatusChanged("preparing");
     fileToBeUploaded = new QFile(filename);
+    if (!fileToBeUploaded->exists()) {
+        emit uploadStatusChanged("failed");
+        return;
+    }
 
     QUrl url("http://uploads.gdata.youtube.com/resumable/feeds/api/users/default/uploads");
     QByteArray xml("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" \
@@ -118,6 +123,7 @@ void YouTube::setUploadUrl() {
     }
     else {
         emit alert(tr("Error - Server repsonse is: ") + statusText);
+        emit uploadStatusChanged("failed");
     }
 }
 
@@ -132,7 +138,7 @@ void YouTube::performVideoUpload() {
     uploadReply = nam->put(request, fileToBeUploaded);
     connect(uploadReply, SIGNAL(uploadProgress(qint64,qint64)), this, SIGNAL(updateUploadProgress(qint64,qint64)));
     connect(uploadReply, SIGNAL(finished()), this, SLOT(uploadFinished()));
-    emit uploadStarted();
+    emit uploadStatusChanged("started");
 }
 
 void YouTube::resumeVideoUpload() {
@@ -161,13 +167,13 @@ void YouTube::resumeVideoUpload() {
     uploadReply = nam->put(request, fileToBeUploaded);
     connect(uploadReply, SIGNAL(uploadProgress(qint64,qint64)), this, SIGNAL(updateUploadProgress(qint64,qint64)));
     connect(uploadReply, SIGNAL(finished()), this, SLOT(uploadFinished()));
-    emit uploadStarted();
+    emit uploadStatusChanged("started");
 }
 
 void YouTube::abortVideoUpload() {
     uploadReply->abort();
     fileToBeUploaded->close();
-    emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "<font>");
+    emit uploadStatusChanged("aborted");
 }
 
 void YouTube::uploadFinished() {
@@ -175,24 +181,24 @@ void YouTube::uploadFinished() {
 
     if (uploadReply->error()) {
         if (uploadReply->error() == QNetworkReply::OperationCanceledError) {
-            emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "</font>");
+            emit uploadStatusChanged("aborted");
             return;
         }
         else {
             int statusCode = uploadReply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
             if (statusCode == 308) {
                 if (uploadRetries > 0) {
-                    emit uploadCompleted("<font color='yellow'>" + tr("Upload interrupted. Attempting to resume...") + "</font>");
+                    emit uploadStatusChanged("interrupted");
                     QTimer::singleShot(3000, this, SLOT(resumeVideoUpload()));
                 }
                 else {
-                    emit uploadCompleted("<font color='red'>" + tr("Upload failed") + "</font>");
+                    emit uploadStatusChanged("failed");
                 }
             }
         }
     }
     else {
-        emit uploadCompleted("<font color='green'>" + tr("Upload is completed") + "</font>");
+        emit uploadStatusChanged("completed");
     }
 }
 
