@@ -91,7 +91,7 @@ signals:
     void videoRated();
     void cannotRate();
     void updateUploadProgress(qint64 bytesSent, qint64 bytesTotal);
-    void uploadCompleted(const QString &status);
+    void uploadStatusChanged(const QString &status);
 };
 
 #endif // YouTube_H
